import { PostfachMailE2EComponent } from 'apps/alfa-e2e/src/components/postfach/postfach-mail.e2e.component';
import { E2EAppHelper } from 'apps/alfa-e2e/src/helper/app.helper';
import { E2EVorgangNavigator } from 'apps/alfa-e2e/src/helper/vorgang/vorgang.navigator';
import { CommandE2E, CommandOrderE2E, CommandStatusE2E } from 'apps/alfa-e2e/src/model/command';
import { createCommand, initCommand } from 'apps/alfa-e2e/src/support/command-util';
import {
  createPostfachNachrichtAttachedItem,
  createSendPostfachNachrichtItem,
} from 'apps/alfa-e2e/src/support/postfach-nachricht.util';
import { initVorgangAttachedItem } from 'apps/alfa-e2e/src/support/vorgang-attached-item-util';
import { VorgangE2E } from '../../../model/vorgang';
import { PostfachMailItemE2E, VorgangAttachedItemE2E } from '../../../model/vorgang-attached-item';
import { containsSpinner } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { exist } from '../../../support/cypress.util';
import { createVorgang, initVorgang, objectIds } from '../../../support/vorgang-util';

describe('Postfach Nachricht pending send', () => {
  const appHelper: E2EAppHelper = new E2EAppHelper();

  const vorgangNavigator: E2EVorgangNavigator = new E2EVorgangNavigator();

  const vorgangPage: VorgangPage = new VorgangPage();
  const postfachMailContainer: PostfachMailE2EComponent = vorgangPage.getPostfachMailcontainer();

  const vorgangWithPendingSendCommand: VorgangE2E = { ...createVorgang(), name: 'VorgangWithPendingSendCommand' };
  const postfachSendNachrichtItem: PostfachMailItemE2E = {
    ...createSendPostfachNachrichtItem(),
    sentSuccessful: false,
  };
  const postfachNachrichtAttachedItem: VorgangAttachedItemE2E = {
    ...createPostfachNachrichtAttachedItem(objectIds[1], vorgangWithPendingSendCommand._id.$oid),
    item: postfachSendNachrichtItem,
  };
  const pendingSendCommand: CommandE2E = {
    ...createCommand(),
    order: CommandOrderE2E.SEND_POSTFACH_NACHRICHT,
    status: CommandStatusE2E.PENDING,
    finishedAt: null,
    body: postfachSendNachrichtItem,
  };

  before(() => {
    initVorgang(vorgangWithPendingSendCommand);
    initVorgangAttachedItem([postfachNachrichtAttachedItem]);
    initCommand(pendingSendCommand);

    appHelper.loginAsSabine();
  });

  describe('area in vorgang detail', () => {
    it('should have item in list', () => {
      vorgangNavigator.openVorgang(vorgangWithPendingSendCommand.name);

      exist(postfachMailContainer.getListItem(postfachSendNachrichtItem.subject).getRoot());
    });

    it('should show spinner on buttons', () => {
      containsSpinner(postfachMailContainer.getCreateButtonWithText());
      containsSpinner(postfachMailContainer.getCreateButtonWithoutText());
    });

    it('should show edit button', () => {
      exist(postfachMailContainer.getListItem(postfachSendNachrichtItem.subject).getEditButton());
    });
  });
});
