/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BasicDialogE2EComponent } from '../components/basic-dialog/basic-dialog.e2e.component';
import { BuildInfoE2EComponent } from '../components/buildinfo/buildinfo.e2e.component';
import { HintE2EComponent } from '../components/hint/hint.component.e2e';
import { NavigationE2EComponent } from '../components/navigation/navigation.e2e.component';
import {
  ConnectionTimeoutRetryDialogE2EComponent,
  ConnectionTimeoutRetryFailDialogE2EComponent,
} from '../components/ui/connection-timeout-retry-dialog.e2e.component';
import { InternalServerErrorDialogE2EComponent } from '../components/ui/internal-server-error-diaog.e2e.component';
import { SnackBarE2EComponent } from '../components/ui/snackbar.e2e.component';
import { VorgangListE2EComponent } from '../components/vorgang/vorgang-list.e2e.component';
import { VorgangViewsE2EComponent } from '../components/vorgang/vorgang-views.e2e.component';
import { getTestElementWithClass } from '../support/cypress-helper';
import { exist, notExist } from '../support/cypress.util';
import { HeaderE2EComponent } from './header.po';

export class MainPage {
  public static readonly SPINNER: string = 'spinner';

  private readonly buildInfo: BuildInfoE2EComponent = new BuildInfoE2EComponent();
  private readonly header: HeaderE2EComponent = new HeaderE2EComponent();
  private readonly navigation: NavigationE2EComponent = new NavigationE2EComponent();
  private readonly views: VorgangViewsE2EComponent = new VorgangViewsE2EComponent();
  private readonly snackBar: SnackBarE2EComponent = new SnackBarE2EComponent();
  private readonly vorgangList: VorgangListE2EComponent = new VorgangListE2EComponent();
  private readonly internalServerErrorDialog: InternalServerErrorDialogE2EComponent = new InternalServerErrorDialogE2EComponent();
  private readonly connectionTimeoutRetryDialog: ConnectionTimeoutRetryDialogE2EComponent =
    new ConnectionTimeoutRetryDialogE2EComponent();
  private readonly connectionTimeoutRetryFailDialog: ConnectionTimeoutRetryFailDialogE2EComponent =
    new ConnectionTimeoutRetryFailDialogE2EComponent();
  private readonly basicDialog: BasicDialogE2EComponent = new BasicDialogE2EComponent();
  private readonly hint: HintE2EComponent = new HintE2EComponent();

  public getBuildInfo(): BuildInfoE2EComponent {
    return this.buildInfo;
  }

  public getHeader(): HeaderE2EComponent {
    return this.header;
  }

  public getNavigation(): NavigationE2EComponent {
    return this.navigation;
  }

  public getViews(): VorgangViewsE2EComponent {
    return this.views;
  }

  public getSnackBar(): SnackBarE2EComponent {
    return this.snackBar;
  }

  public getVorgangList(): VorgangListE2EComponent {
    return this.vorgangList;
  }

  public getInternalServerErrorDialog(): InternalServerErrorDialogE2EComponent {
    return this.internalServerErrorDialog;
  }

  public getConnectionTimeoutRetryDialog(): ConnectionTimeoutRetryDialogE2EComponent {
    return this.connectionTimeoutRetryDialog;
  }

  public getConnectionTimeoutRetryFailDialog(): ConnectionTimeoutRetryFailDialogE2EComponent {
    return this.connectionTimeoutRetryFailDialog;
  }

  public getBasicDialog(): BasicDialogE2EComponent {
    return this.basicDialog;
  }

  public getHint(): HintE2EComponent {
    return this.hint;
  }
}

export function waitForSpinnerToDisappear(): void {
  notExist(getSpinner());
}

export function getSpinner(): Cypress.Chainable<JQuery<Element>> {
  return getTestElementWithClass(MainPage.SPINNER);
}

export function containsSpinner(rootElement: Cypress.Chainable<JQuery<Element>>): void {
  exist(rootElement.findTestElementWithClass(MainPage.SPINNER));
}

//TODO Funktion loeschen
export function waitforSpinnerToAppear(): void {
  // exist(cy.getTestElementWithClass('spinner'));
}
//
