/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { PostfachMailLinkRel, PostfachService } from '@alfa-client/postfach-shared';
import { createEmptyStateResource, createStateResource, HasLinkPipe, StateResource } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, Mock, mock, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createCommandResource } from 'libs/command-shared/test/command';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { createPostfachMailResource } from '../../../../../../../../postfach-shared/test/postfach';
import { singleColdCompleted } from '../../../../../../../../tech-shared/test/marbles';
import { OutgoingMailErrorContainerComponent } from './outgoing-mail-error-container.component';
import { OutgoingMailErrorComponent } from './outgoing-mail-error/outgoing-mail-error.component';

describe('OutgoingMailErrorContainerComponent', () => {
  let component: OutgoingMailErrorContainerComponent;
  let fixture: ComponentFixture<OutgoingMailErrorContainerComponent>;

  let postfachService: Mock<PostfachService>;

  const mailError: string = getDataTestIdOf('outgoing-mail-error');

  beforeEach(async () => {
    postfachService = mock(PostfachService);

    await TestBed.configureTestingModule({
      declarations: [OutgoingMailErrorContainerComponent, MockComponent(OutgoingMailErrorComponent), HasLinkPipe],
      providers: [
        {
          provide: PostfachService,
          useValue: postfachService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(OutgoingMailErrorContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('resendMail', () => {
    const commandStateResource: StateResource<CommandResource> = createStateResource(createCommandResource());

    beforeEach(() => {
      postfachService.resendMail.mockReturnValue(of(commandStateResource));
    });

    it('should call postfach service', () => {
      component.resendMail();

      expect(postfachService.resendMail).toHaveBeenCalled();
    });

    it('should assign service response', () => {
      component.resendPostfachMailStateResource$ = of(createEmptyStateResource<CommandResource>());

      component.resendMail();

      expect(component.resendPostfachMailStateResource$).toBeObservable(singleColdCompleted(commandStateResource));
    });
  });

  describe('outgoing mail error', () => {
    it('should show', () => {
      component.postfachMailResource = createPostfachMailResource([PostfachMailLinkRel.RESEND_POSTFACH_MAIL]);

      fixture.detectChanges();

      existsAsHtmlElement(fixture, mailError);
    });

    it('should hide', () => {
      component.postfachMailResource = createPostfachMailResource();

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, mailError);
    });
  });
});
